

!!! Listing 1

!!! Titel: Shell-Script

#!/bin/sh

# CeBIT-Daten aus Datenbank in XML ausgeben

CHOME=/path/to/cebit2000
FILE=$CHOME/cebit2000
# Pfade fuer die DB, beispielsweise:
PATH=${PATH}:/path/to/db-system/bin
export CHOME FILE PATH

cd $CHOME
mv $FILE.xml $FILE.xml.old
echo '<?xml version="1.0" encoding="ISO-8859-1" standalone="no"?>' > $FILE.xml
echo "" >> $FILE.xml
echo '<!DOCTYPE cebit SYSTEM "cebit.dtd">' >> $FILE.xml
echo "" >> $FILE.xml
echo "<cebit>" >> $FILE.xml
echo "" >> $FILE.xml

# eigentlicher DB-Report (hier: Informix)
${DB-SYSTEMDIR}/bin/sacego -q $FILE.arc >> $FILE.xml

echo "" >> $FILE.xml
echo "</cebit>" >> $FILE.xml
echo "" >> $FILE.xml

!!! Listing 2

!!! Titel: Auszug aus den XML-Daten

<cebit>
   <appsrv  thema="appsrv" longname="Application Server">
     <group which="1">
       <firma url="www.firma.com">
         <name>Wonder Corporation</name>
         <halle>     4</halle>
         <stand>G42 [bei Galaxy, Inc.]</stand>
         <produkt>WebHiker's Guide</produkt>
       </firma>
       <!-- weitere Firmen -->
      </group>
      <!-- weitere Fuenfergruppen -->
   </appsrv>
      <!-- weitere Produktgruppen -->
</cebit>

!!! Listing 3

!!! Titel: XSLT-Script

<?xml version="1.0" encoding="ISO-8859-1"?>

<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns="http://www.wapforum.org/DTD/wml_1.1.xml"
  xmlns:saxon="http://icl.com/saxon"
  saxon:trace="no"
  extension-element-prefixes="saxon">

<!-- Parameter  und Variable -->
<xsl:variable name="dir">wml</xsl:variable>
<xsl:variable name="filesep" select="system-property('file.separator')" />
<xsl:variable name="islastgroup"/>
<xsl:variable name="isfirstgroup"/>
<xsl:variable name="currentgroup"/>
<xsl:variable name="grpno"/>

<!-- ....................Root............... -->
<xsl:template match="/">
  <xsl:apply-templates/>
</xsl:template>

<!-- ............Element cebit............... -->
<xsl:template match="/cebit">
  <xsl:apply-templates/>
</xsl:template>

<!-- ......P r o d u k t g r u p p e n......  -->
<xsl:template match="appsrv|bluet|datam|intzu|java|
                     linux|pki|san|sysm|unis|viren|wap|wbt">
  <saxon:assign name="currentgroup">
   <xsl:value-of select="@thema"/>
  </saxon:assign>
  <xsl:apply-templates select="group" mode="detail"/>
</xsl:template>


<!-- Ausgabe der kleinen Gruppen (maximal fuenf Firmen) -->
<xsl:template match="group" mode="detail">
  <saxon:set-attribute name="thispos" select="position()"/>
  <saxon:assign name="islastgroup" 
		select="position()=last()"/>
  <saxon:assign name="isfirstgroup" 
		select="position()=1"/>
  <xsl:variable name="grpno">
    <xsl:value-of select="@thispos"/>
  </xsl:variable>

  <saxon:output file="{$dir}{$filesep}{$currentgroup}{$grpno}.wml"
    method="xml" indent="yes"
    doctype-public="-//WAPFORUM//DTD WML 1.1//EN"
    doctype-system="http://www.wapforum.org/DTD/wml_1.1.xml">
  <wml>
    <template>
    <do type="options" label="Top">
     <go href="index.wml" />
    </do>
    </template>
    <xsl:apply-templates select="firma" mode="longish"/>
  </wml>
  </saxon:output>
</xsl:template>

<!-- ................ Firmendaten............ -->

<xsl:template match="firma" mode="longish">
  <card>
   <xsl:attribute name="id">
     <xsl:value-of select="$currentgroup"/>
     <xsl:value-of select="position()"/>
   </xsl:attribute>
   <xsl:attribute name="title">
     <xsl:value-of select="../../@longname"/>
   </xsl:attribute>

    <p>
        <strong>
        <xsl:apply-templates select="name"/>
        </strong>
        <br/>
        <xsl:text>Halle</xsl:text>
        <xsl:apply-templates select="halle"/>
        <xsl:text>, Stand </xsl:text>
        <xsl:apply-templates select="stand"/>
        <br/>
        <xsl:text>Produkt: </xsl:text>
        <xsl:apply-templates select="produkt"/>
    </p>
<!-- Next Button -->
    <xsl:choose>
      <xsl:when test="not (position()=last())">
       <do>
         <xsl:attribute name="type">accept</xsl:attribute>
         <xsl:attribute name="label">Next</xsl:attribute>

         <go>
           <xsl:attribute name="href">
             <xsl:text>#</xsl:text>
             <xsl:value-of select="$currentgroup"/>
             <xsl:number value="position() + 1"/>
           </xsl:attribute>
         </go>
       </do>
      </xsl:when>
<!-- letzte Firma... -->
       <xsl:otherwise>
<!-- aber _nicht_ die letzte der Gruppen in diesem Segment -->
       <xsl:if test="not($islastgroup)">
        <do>
         <xsl:attribute name="type">accept</xsl:attribute>
         <xsl:attribute name="label">Next</xsl:attribute>

         <go>
           <xsl:attribute name="href">
             <xsl:value-of select="../@thema"/>
             <xsl:value-of select="../@which + 1"/>
             <xsl:text>.wml</xsl:text>
           </xsl:attribute>
         </go>
        </do>
       </xsl:if>
       </xsl:otherwise>
     </xsl:choose>
<!-- Prev-Button -->
    <xsl:choose>
      <xsl:when test="not (position()=1)">
       <do>
         <xsl:attribute name="type">prev</xsl:attribute>
         <xsl:attribute name="label">Prev</xsl:attribute>

         <go>
           <xsl:attribute name="href">
             <xsl:text>#</xsl:text>
             <xsl:value-of select="$currentgroup"/>
             <xsl:number value="position() - 1"/>
           </xsl:attribute>
         </go>
       </do>
      </xsl:when>
<!-- erste Firma... -->
       <xsl:otherwise>
<!-- aber _nicht_ die erste der Gruppen in diesem Segment -->
       <xsl:if test="not($isfirstgroup)">
        <do>
         <xsl:attribute name="type">prev</xsl:attribute>
         <xsl:attribute name="label">Prev</xsl:attribute>

         <go>
           <xsl:attribute name="href">
             <xsl:value-of select="$currentgroup"/>
             <xsl:value-of select="../@which - 1"/>
             <xsl:text>.wml#</xsl:text>
             <xsl:value-of select="$currentgroup"/>
             <xsl:text>5</xsl:text>
           </xsl:attribute>
         </go>
        </do>
       </xsl:if>
       </xsl:otherwise>
     </xsl:choose>
  </card>
</xsl:template>

<!-- Liste der Firmennamens pro Produktgruppe -->

<!-- Templates fuer Name, Halle, Stand, Produkt in
     main.xsl, weil fuer alle Stylesheets identisch -->

<xsl:template match="name">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="halle">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="stand">
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="produkt">
    <xsl:apply-templates/>
</xsl:template>

</xsl:stylesheet>


!!! Listing 4

!!! Titel: Nachbearbeitung der WML-Daten

#!/bin/sh

Pfad=/pfad/zu/einem/wml/verzeichnis

for i in wml/*
do
  sed -f w.sedscript $i | utf2ae | tr "\015" "\012" > $Pfad/$i \
  && echo " - transferred $i"
done

!!! Listing 5

!!! Titel: MIME-Typen

text/vnd.wap.wml                wml
application/vnd.wap.wmlc        wmlc
text/vnd.wap.wmlscript          wmls
application/vnd.wap.wmlscriptc  wmlsc

!!! Listing 6

<!-- ........................Produktgruppen..............  -->
<xsl:template match="appsrv|bluet|datam|intzu|java|
                     linux|pki|san|sysm|unis|viren|wap|wbt">
  <xsl:variable name="thisandnow">
    <xsl:value-of select="@thema"/>
  </xsl:variable>
  <saxon:output file="{$dir}{$filesep}{$thisandnow}.wml"
    method="xml" indent="yes"
    doctype-public="-//WAPFORUM//DTD WML 1.1//EN"
    doctype-system="http://www.wapforum.org/DTD/wml_1.1.xml">
  <wml>
     <card>
        <xsl:attribute name="id">
         <xsl:value-of select="@thema"/>
        </xsl:attribute>
        <xsl:attribute name="title">
          <xsl:value-of select="@longname"/>
        </xsl:attribute>
        <xsl:apply-templates select="group" mode="complist"/>
     </card>
  </wml>
  </saxon:output>
  <xsl:apply-templates select="group" mode="detail"/>
</xsl:template>

<!-- ........................Liste der Firmen.............. -->
<xsl:template match="group" mode="complist">
      <xsl:apply-templates select="firma" mode="pur"/>
</xsl:template>

<xsl:template match="group" mode="detail">
  <saxon:set-attribute name="diesthema" select="@thema"/>
  <saxon:set-attribute name="diesenummer" select="position()"/>
  <xsl:variable name="thisandnow">
    <xsl:value-of select="@diesthema"/>
  </xsl:variable>
  <xsl:variable name="grpno">
    <xsl:value-of select="@diesenummer"/>
  </xsl:variable>

  <saxon:output file="{$dir}{$filesep}{$thisandnow}{$grpno}.wml"
    method="xml" indent="yes"
    doctype-public="-//WAPFORUM//DTD WML 1.1//EN"
    doctype-system="http://www.wapforum.org/DTD/wml_1.1.xml">
  <wml>
    <xsl:apply-templates select="firma" mode="longish"/>
  </wml>
  </saxon:output>
</xsl:template>

<!-- Firmennamen -->
<xsl:template match="firma" mode="pur">
  <xsl:variable name="compno">
    <xsl:number count="firma"/>
  </xsl:variable>
  <a>
    <xsl:attribute name="href">
      <xsl:value-of select="$currentgroup"/>
      <xsl:value-of select="ancestor::group/@which"/>
      <xsl:text>.wml#</xsl:text>
      <xsl:value-of select="$currentgroup"/>
      <xsl:number value="$compno"/>
    </xsl:attribute>
    <xsl:apply-templates select="name"/>
   </a>
   <xsl:if test="not(position()=last())"><br/></xsl:if>
</xsl:template>
